#
# spec file for package syslogd
#
# Copyright (c) 2022 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


#Compat macro for new _fillupdir macro introduced in Nov 2017
%if ! %{defined _fillupdir}
  %define _fillupdir /var/adm/fillup-templates
%endif

%if ! %{defined _rundir}
%define _rundir %{_localstatedir}/run
%endif
Name:           syslogd
Version:        1.5.1
Release:        803.2
Summary:        The Syslog daemon
License:        GPL-2.0-or-later
Group:          System/Daemons
URL:            https://www.infodrom.org/projects/sysklogd/
Source:         https://www.infodrom.org/projects/sysklogd/download/sysklogd-%{version}.tar.gz
#Source4:        https://www.infodrom.org/projects/sysklogd/download/sysklogd-%{version}.tar.gz.asc
Source1:        logrotate.syslog
Source2:        sysconfig.syslogd
Source3:        sysconfig.klogd
Source5:        syslog.8
Source6:        klog.service
Source7:        klogd.service
Source8:        syslogd.service
Source9:        syslogd-service-prepare
Source11:       syslogd-rpmlintrc
Source12:       sysconfig.boot
Patch0:         sysklogd-1.4.1.dif
Patch1:         sysklogd-1.4.1-dgram.patch
Patch2:         sysklogd-1.4.1-sparc.patch
Patch3:         sysklogd-1.4.1-forw.patch
Patch5:         sysklogd-ipv6.diff
Patch6:         sysklogd-1.4.1-klogd24.dif
Patch7:         sysklogd-1.4.1-large.patch
Patch8:         sysklogd-1.4.1-dns.patch
Patch9:         sysklogd-1.4.1-reopen.patch
Patch12:        sysklogd-1.4.1-ksyslogsize.diff
Patch13:        sysklogd-1.4.1-unix_sockets.patch
Patch14:        sysklogd-1.4.1-showpri.patch
Patch18:        sysklogd-1.4.1-dontsleep.patch
Patch19:        sysklogd-1.4.1-signal.dif
Patch20:        sysklogd-1.4.1-clearing.patch
Patch21:        sysklogd-1.4.1-nofortify.patch
Patch22:        sysklogd-1.4.1-sysmap-prior-to-2.5.patch
Patch23:        sysklogd-1.4.1-reload.dif
Patch24:        sysklogd-1.4.1-systemd.dif
Patch25:        sysklogd-1.4.1-systemd-multi.dif
Patch26:        sysklogd-1.4.1-systemd-sock-name.patch
# PATCH-FIX-SUSE bsc#897262, CVE-2014-3634 rsyslog/syslogd: remote syslog PRI vulnerability
Patch28:        sysklogd-1.4.1-CVE-2014-3634.patch
BuildRequires:  pkgconfig
BuildRequires:  group(news)
BuildRequires:  pkgconfig(libsystemd)
BuildRequires:  pkgconfig(systemd)
BuildRequires:  user(news)
Requires:       klogd
Requires(post): %fillup_prereq
Requires(post): permissions
# Note: this package is for >= 12.3 only
# and does not provide LSB init scripts!
Requires(pre):  syslog-service >= 2.0
Requires(pre):  user(news)
Requires(pre):  group(news)
Conflicts:      syslog
Provides:       sysklogd
Provides:       syslog
Provides:       sysvinit(syslog)
BuildRoot:      %{_tmppath}/%{name}-%{version}-build
%{?systemd_requires}

%description
The syslogd daemon is the general system logging daemon, which is
responsible for handling requests for syslog services.

This version of syslogd is similar to the standard Berkeley product,
but with a number of compatible extensions.

%package -n klogd
Summary:        The kernel log daemon
Group:          System/Daemons
Requires(post): %fillup_prereq

%description -n klogd
The klogd daemon 'listens' to kernel log messages, prioritizes them,
and routes them to either output files or to syslog daemon.

This version of klogd will optionally translate kernel addresses to
their symbolic equivalents if provided with a system map.

%package -n syslog-service
Version:        2.0
Release:        803.2
Summary:        Syslog service files & scripts
Group:          System/Daemons
Requires:       logrotate
Requires:       syslog
Requires:       sysvinit(network)
Requires(post): %fillup_prereq
BuildArch:      noarch

%description -n syslog-service
The package syslog-service provides the service boot
scripts for SysV and the service unit files for systemd.

%prep
%setup -q -n sysklogd-1.5.1
%patch -P 1   -b .dgram
%patch -P 2   -b .sparc
%patch -P 3   -b .forw
%patch -P 5   -b .ipv6
%patch -P 6   -b .klogd24
%patch -P 7   -b .large
%patch -P 8   -b .dns
%patch -P 9   -b .reopen
%patch -P 12  -b .klsize
%patch -P 13  -b .usock
%patch -P 14  -b .shprio
%patch -P 18  -b .sleep
%patch -P 19  -b .signal
%patch -P 20  -b .clear
%patch -P 21  -b .nofortify
%patch -P 22  -b .sysmap
%patch -P 23  -b .reload
%patch -P 24  -b .sd
%patch -P 25  -b .sd2
%patch -P 26  -b .sd3
%patch -P 28  -b .cve20143634
%patch -P 0 -b .p0

%build
%ifarch s390 s390x
mv sample-s390.conf sample.conf
%endif
# honor the increased LOG_BUF_LEN in kernel/printk.c
make %{?_smp_mflags} BINDIR=%{_sbindir} LOG_BUFFER_SIZE=-DLOG_BUFFER_SIZE=131072

%install
mkdir -p %{buildroot}/etc
mkdir -p %{buildroot}/sbin
mkdir -p %{buildroot}/%{_sbindir}
mkdir -p %{buildroot}/%{_mandir}/man{5,8}
mkdir -p %{buildroot}%{_fillupdir}
mkdir -p %{buildroot}%{_unitdir}
mkdir -p -m 0755 %{buildroot}/%{_rundir}/syslogd
make install MANDIR=%{_mandir} BINDIR=%{_sbindir} DESTDIR=%{buildroot}
%if 0%{?suse_version} > 1500
mkdir -p %{buildroot}%{_distconfdir}/logrotate.d
install -m 644 %{SOURCE1} %{buildroot}%{_distconfdir}/logrotate.d/syslog
%else
mkdir -p %{buildroot}%{_sysconfdir}/logrotate.d
install -m 644 %{SOURCE1} %{buildroot}%{_sysconfdir}/logrotate.d/syslog
%endif
install -m 644 %{SOURCE2} %{buildroot}%{_fillupdir}
install -m 644 %{SOURCE3} %{buildroot}%{_fillupdir}
install -m 644 %{SOURCE5} %{buildroot}/%{_mandir}/man8/syslog.8
install -m 644 %{SOURCE6} %{buildroot}%{_unitdir}/
install -m 644 %{SOURCE7} %{buildroot}%{_unitdir}/
install -m 644 %{SOURCE8} %{buildroot}%{_unitdir}/
install -m 755 %{SOURCE9} %{buildroot}/%{_sbindir}/
ln -s service %{buildroot}/%{_sbindir}/rcsyslogd
install -m 644 %{SOURCE12} %{buildroot}%{_fillupdir}
%if 0%{?suse_version} < 1550
for sbin in klogd syslogd ; do
	ln -sf %{_sbindir}/${sbin} %{buildroot}/sbin/${sbin}
done
%endif
%ifarch s390 s390x
sed -i 's/^KERNEL_LOGLEVEL=1/KERNEL_LOGLEVEL=7/' \
%{buildroot}%{_fillupdir}/sysconfig.klogd
%endif

%if %{defined verify_permissions}
%verifyscript
%verify_permissions -e %{_sysconfdir}/syslog.conf
%endif

%pre
%service_add_pre syslogd.service

%post
%set_permissions %{_sysconfdir}/syslog.conf
#
# add syslog variables provided by syslogd if needed
#
%{remove_and_set -n syslog SYSLOG_DAEMON}
%{remove_and_set -n syslog SYSLOG_REQUIRES_NETWORK}
%{fillup_only -ns syslog syslogd}
#
# create dirs, touch log default files
#
mkdir -p var/log
touch var/log/messages;  chmod 640 var/log/messages
touch var/log/mail;      chmod 640 var/log/mail
touch var/log/mail.info; chmod 640 var/log/mail.info
touch var/log/mail.warn; chmod 640 var/log/mail.warn
touch var/log/mail.err;  chmod 640 var/log/mail.err
test -f var/log/news && mv var/log/news var/log/news.bak
mkdir -p -m 0750 var/log/news
chown news:news  var/log/news
touch var/log/news/news.crit;   chmod 640 var/log/news/news.crit
chown news:news var/log/news/news.crit
touch var/log/news/news.err;    chmod 640 var/log/news/news.err
chown news:news var/log/news/news.err
touch var/log/news/news.notice; chmod 640 var/log/news/news.notice
chown news:news var/log/news/news.notice
#
# Enable the syslogd as service
#
# This macro enables based on a systemctl preset config file only
%service_add_post syslogd.service
# But we want to enable a syslog-daemon regardless of the preset;
# force the creation of a syslog.service alias link (bnc#790805).
# We do not check the obsolete SYSLOG_DAEMON variable as we want
# to switch when installing it and there is a provider conflict.
%{_bindir}/systemctl -f enable syslogd.service >/dev/null 2>&1 || :

%preun
%service_del_preun syslog.socket
%service_del_preun syslogd.service

%postun
%service_del_postun syslogd.service

%preun  -n syslog-service
%service_del_preun klog.service

%post -n syslog-service -p /bin/bash
%{remove_and_set -n syslog SYSLOG_DAEMON}
%{remove_and_set -n syslog SYSLOG_REQUIRES_NETWORK}
%{remove_and_set -n boot KLOGCONSOLE_PARAMS}
%{fillup_only -n boot}
#BEGIN KLOGCONSOLE_PARAMS migration
# KLOGCONSOLE_PARAMS was supported in /etc/sysconfig/boot up to Leap 15 and SLE 15.
# Based on genopts-1.3 options parser.
if test "$KLOGCONSOLE_PARAMS" != "no" ; then
 KLOG_CONSOLE=
 CONSOLE_LOGLEVEL=
 function optarg_parse {
  until [ $# -eq 0 ] ; do
   case "$1" in
   -* )
    OPTTMP="${1:1}"
    until [[ -z "$OPTTMP" ]] ; do
     case "${OPTTMP:0:1}" in
     r )
      KLOG_CONSOLE="${OPTTMP:1}"
      if [[ -z "$KLOG_CONSOLE" ]] ; then
       shift
       KLOG_CONSOLE="$1"
      else
       break
      fi
      ;;
     l )
      CONSOLE_LOGLEVEL="${OPTTMP:1}"
      if [[ -z "$CONSOLE_LOGLEVEL" ]] ; then
       shift
       CONSOLE_LOGLEVEL="$1"
      else
       break
      fi
      ;;
     esac
     OPTTMP="${OPTTMP:1}"
    done
    ;;
   esac
   shift
  done
 }
 optarg_parse $KLOGCONSOLE_PARAMS
 case "$CONSOLE_LOGLEVEL" in
 0) CONSOLE_LOGLEVEL=emerg ;;
 1) CONSOLE_LOGLEVEL=alert ;;
 2) CONSOLE_LOGLEVEL=crit ;;
 3) CONSOLE_LOGLEVEL=err ;;
 4) CONSOLE_LOGLEVEL=warning ;;
 5) CONSOLE_LOGLEVEL=notice ;;
 6) CONSOLE_LOGLEVEL=info ;;
 7) CONSOLE_LOGLEVEL=debug ;;
 esac
 unset OPTTMP
cat >%{_sysconfdir}/sysconfig/boot.update <<EOF
## Path:		System/Logging
## Description:		System logging

## Type:		list(1,2,3,4,5,6,7,8,9,10,11,12)
## Default:		10
#
# Console for logging
#
KLOG_CONSOLE="$KLOG_CONSOLE"

## Type:		list(,0,emerg,1,alert,2,crit,3,err,4,warning,5,notice,6,info,7,debug)
## Default:
#
# Loglevel for log console
#
CONSOLE_LOGLEVEL="$CONSOLE_LOGLEVEL"
EOF
 fillup -m %{_sysconfdir}/sysconfig/boot.update %{_sysconfdir}/sysconfig/boot %{_sysconfdir}/sysconfig/boot
 rm %{_sysconfdir}/sysconfig/boot.update
fi
#END KLOGCONSOLE_PARAMS migration

# when exists, remove the broken link pointing to the
# common syslog.service file, we've provided before...
rm -f %{_sysconfdir}/systemd/system/multi-user.target.wants/syslog.service
%service_add_post klog.service
%{_bindir}/systemctl -f enable klog.service >/dev/null 2>&1 || :

%pre -n syslog-service
%service_add_pre klog.service
%if 0%{?suse_version} > 1500
# Prepare for migration to /usr/etc; save any old .rpmsave
for i in logrotate.d/syslog ; do
   test -f %{_sysconfdir}/${i}.rpmsave && mv -v %{_sysconfdir}/${i}.rpmsave %{_sysconfdir}/${i}.rpmsave.old ||:
done
%endif

%if 0%{?suse_version} > 1500
%posttrans  -n syslog-service
# Migration to /usr/etc, restore just created .rpmsave
for i in logrotate.d/syslog ; do
   test -f %{_sysconfdir}/${i}.rpmsave && mv -v %{_sysconfdir}/${i}.rpmsave %{_sysconfdir}/${i} ||:
done
%endif

%postun -n syslog-service
%service_del_postun klog.service

%pre -n klogd
%service_add_pre klogd.service

%post -n klogd
#
# add syslog variables provided by klogd if needed
#
%{remove_and_set -n syslog SYSLOG_DAEMON}
%{remove_and_set -n syslog SYSLOG_REQUIRES_NETWORK}
%{fillup_only -ns syslog klogd}
#
# Enable the syslogd as service
#
%service_add_post klogd.service

%preun -n klogd
%service_del_preun klogd.service

%postun -n klogd
%service_del_postun klogd.service

%files
%defattr(-,root,root)
%{_fillupdir}/sysconfig.syslogd
%config %verify(not mode) %attr(0600,root,root) %{_sysconfdir}/syslog.conf
%{_mandir}/man5/syslog.conf.5%{ext_man}
%{_mandir}/man8/syslogd.8%{ext_man}
%{_mandir}/man8/sysklogd.8%{ext_man}
%{_unitdir}/syslogd.service
%{_sbindir}/syslogd-service-prepare
%attr(0755,root,root) %dir %ghost %{_rundir}/syslogd
%{_sbindir}/syslogd
%{_sbindir}/rcsyslogd
%if 0%{?suse_version} < 1550
/sbin/syslogd
%endif

%files -n klogd
%defattr(-,root,root)
%{_fillupdir}/sysconfig.klogd
%{_unitdir}/klogd.service
%{_mandir}/man8/klogd.8%{ext_man}
%{_sbindir}/klogd
%if 0%{?suse_version} < 1550
/sbin/klogd
%endif

%files -n syslog-service
%defattr(-,root,root)
%{_fillupdir}/sysconfig.boot
%if 0%{?suse_version} > 1500
%{_distconfdir}/logrotate.d/syslog
%else
%config(noreplace) %{_sysconfdir}/logrotate.d/syslog
%endif
%{_unitdir}/klog.service
%{_mandir}/man8/syslog.8%{ext_man}

%changelog
* Mon Feb 26 2024 Dominique Leuenberger <dimstar@opensuse.org>
- Use %%patch -P N instead of deprecated %%patchN.
* Tue Dec 27 2022 Ludwig Nussel <lnussel@suse.com>
- Replace transitional %%usrmerged macro with regular version check (boo#1206798)
* Wed Oct 19 2022 Dr. Werner Fink <werner@suse.de>
- Update ot version 1.5.1
  ChangeLog for version 1.5.1
    Many thanks to Rainer Gerhards, rsyslog project lead, for
    identifying a problem with how rsyslog's rsyslogd and sysklogd's
    syslogd check for invalid priority values (CVE-2014-3634).
  ChangeLog for version 1.5
  * Fix file descriptor leak in klogd
  * Improve argument list processing
  * Prevent potential buffer overflow in reading messages from the
    kernel log ringbuffer
  * Ensure that "len" is not placed in a register, and that the endtty()
    signal handler is not installed too early which could cause a
    segmentation fault or worse
  * klogd will reconnect to the logger (mostly syslogd) after it went
    away during operation
  * On heavily loaded system syslog will not spit out error messages
    anymore when recvfrom() results in EAGAIN
  * Makefile improvements
  * Local copy of module.h
  * Improved manpage
  * Always log with syslogd's timezone and locale
  * Remove trailing newline when forwarding messages
  * Continue working properly if /etc/service is missing and ignore
    network activity
  * Continue writing to log files as soon as space becomes available
    again after a filled up disk
  * Removed test to detect control characters> 0x20 as this prevented
    characters encoded in UTF-8 to be properly passed through
  * Only resolve the local domain when accepting messages from remote
  * Properly accompany the MARK message with the facility
  * Improved daemonise routine in klogd to stabilise startup
  * klogd will not change the console log level anymore unless -c is given
  * Added back /usr/src/linux/System.map as fall-back location
  * Rewrite the module symbol parser to read from /proc/kallsyms
  * Notify the waiting parent process if the client dies
  * Complete rewrite of the oops kernel module for Linux 2.6
  * Only read kernel symbols from /proc/kallsyms if no System.map
    has been read
  * Improved symbol lookup
  * Prevent named pipes from becoming the controlling tty
  * Fixing a race condition in syslogd discovered in UML
  * Improved README.linux
  * Added boundary checks in klogd
  * Don't block on the network socket in case of packet loss
  * Don't crash when filesize limit is reached (e.g. without LFS)
  * Fix spurious hanging syslogd in connection with futex and NPTL
    introduced in recent glibc versions and Linux 2.6 (details)
  * Improved syslog.conf(5) manpage
  * Use socklen_t where appropriate
  * Use newer query_module function rather than stepping through /dev/kmem.
  * Remove special treatment of the percent sign in klogd
- Remove patches now upstream solved
  * klogd-obsolete.patch
  * sysklogd-1.4.1-fileleak.patch
  * sysklogd-1.4.1-ksym.patch
  * sysklogd-1.4.1-no_SO_BSDCOMPAT.diff
  * sysklogd-1.4.1-owl-crunch_list.diff
  * sysklogd-1.4.1-preserve_percents.patch
  * sysklogd-1.4.1-utf8.patch
- Port patches
  * sysklogd-1.4.1-CVE-2014-3634.patch
  * sysklogd-1.4.1-clearing.patch
  * sysklogd-1.4.1-dgram.patch
  * sysklogd-1.4.1-dns.patch
  * sysklogd-1.4.1-dontsleep.patch
  * sysklogd-1.4.1-forw.patch
  * sysklogd-1.4.1-klogd24.dif
  * sysklogd-1.4.1-ksyslogsize.diff
  * sysklogd-1.4.1-large.patch
  * sysklogd-1.4.1-nofortify.patch
  * sysklogd-1.4.1-reload.dif
  * sysklogd-1.4.1-reopen.patch
  * sysklogd-1.4.1-showpri.patch
  * sysklogd-1.4.1-signal.dif
  * sysklogd-1.4.1-sparc.patch
  * sysklogd-1.4.1-sysmap-prior-to-2.5.patch
  * sysklogd-1.4.1-systemd-multi.dif
  * sysklogd-1.4.1-systemd-sock-name.patch
  * sysklogd-1.4.1-systemd.dif
  * sysklogd-1.4.1-unix_sockets.patch
  * sysklogd-1.4.1.dif
  * sysklogd-ipv6.diff
* Thu Oct 13 2022 Dr. Werner Fink <werner@suse.de>
- Check ownership of initrd.msg before adding it to boot.msg (bsc#1204245)
* Wed Aug 31 2022 Stefan Schubert <schubi@suse.com>
- Migration to /usr/etc: Saving user changed configuration files
  in /etc and restoring them while an RPM update.
* Tue Jun 21 2022 Stefan Schubert <schubi@suse.com>
- Moved logrotate files from user specific directory /etc/logrotate.d
  to vendor specific directory /usr/etc/logrotate.d.
* Tue Apr 19 2022 Marcus Meissner <meissner@suse.com>
- https urls, added gpg signature (but not the keyring, could not
  find it)
* Fri Mar  4 2022 Dr. Werner Fink <werner@suse.de>
- Switch from obsolete standard output type syslog over to journal (boo#1196467)
* Tue Nov 30 2021 Johannes Segitz <jsegitz@suse.com>
- Remove PrivateDevices, ProtectClock and ProtectKernelLogs=true
  from klog.service and ProtectKernelLogs from klogd.service
  (bsc#1193172)
* Wed Nov 24 2021 Johannes Segitz <jsegitz@suse.com>
- Added hardening to systemd service(s) (bsc#1181400). Modified:
  * klog.service
  * klogd.service
  * syslogd.service
* Tue Nov 24 2020 Ludwig Nussel <lnussel@suse.de>
- prepare usrmerge (boo#1029961)
- replace broken rcsyslog script with rcsyslogd link
* Wed Aug 19 2020 Dr. Werner Fink <werner@suse.de>
- Set permission also in file list for /etc/syslog.conf
* Thu Feb 27 2020 Michael Ströder <michael@stroeder.com>
- Removed create option from logrotate.syslog to let logrotate
  preserve file system ACLs
* Tue Dec 11 2018 Jan Engelhardt <jengelh@inai.de>
- Set /bin/bash as scriptlet interpreter where needed.
* Tue Nov 20 2018 sbrabec@suse.com
- Use setlogcons and dmesg instead of klogconsole;
  perform migration of sysconfig/boot file (boo#1116277).
* Thu Nov 23 2017 rbrown@suse.com
- Replace references to /var/adm/fillup-templates with new
  %%_fillupdir macro (boo#1069468)
* Thu Apr  6 2017 werner@suse.de
- Use socket activation API of the libsystemd
* Thu Mar  9 2017 werner@suse.de
- Require user and group news
* Thu Jul 21 2016 tchvatal@suse.com
- Add requires on klogd, previously in requires(pre); should fix
  issue found in sr#412257
* Mon Jun 27 2016 tchvatal@suse.com
- Cleanup various rpmlint warnings
- Use upstream url and sources
- Remove the omv files, not needed
* Mon Jan 25 2016 schwab@suse.de
- klogd-obsolete.patch: avoid use of obsolete function get_kernel_syms
* Fri May  8 2015 werner@suse.de
- Reintroduce /etc/sysconfig/boot for having KLOGCONSOLE_PARAMS back
* Wed May  6 2015 werner@suse.de
- Modernize systemd service units
* Wed Mar 11 2015 werner@suse.de
- Be aware that klog.service should be handled by the
  systemd rpm macros
* Thu Oct  9 2014 werner@suse.de
- Update patch sysklogd-1.4.1-CVE-2014-3634.patch (boo#899756)
* Mon Sep 29 2014 schwab@suse.de
- sysklogd-1.4.1-reload.dif: remove bogus use of feature test macro
- sysklogd-1.4.1.dif: refresh
- sysklogd-1.4.1-glibc.patch: remove obsolete patch
* Wed Sep 24 2014 werner@suse.de
- Add patch sysklogd-1.4.1-CVE-2014-3634.patch bsc#897262,
  CVE-2014-3634 rsyslog/syslogd: remote syslog PRI vulnerability
* Mon Sep 15 2014 werner@suse.de
- Add patch sysklogd-1.4.1-glibc.patch
  newer glibc versions do not set nor use _BSD_SOURCE anymore
* Mon Sep  1 2014 werner@suse.de
- Klog service: Move the Alias tag from Unit section to the Install
  section bnc#893741
* Fri Aug 22 2014 werner@suse.de
- Add syslogd-rpmlintrc to sourcelist to shut up stupid factory auto
* Fri Aug 22 2014 mt@suse.de
- Stop syslog.socket in %%preun to avoid the daemon we uninstall
  gets started by a log message due to dependencies (bnc#840815).
* Sun May 11 2014 coolo@suse.com
- use %%_rundir macro
* Wed Jan 15 2014 werner@suse.de
- Change klogd.service to use BindsTo instead of BindTo
* Mon Dec  9 2013 werner@suse.de
- Replace `Names' with `Alias' in klog.service (bnc#854315)
* Mon Jul 15 2013 werner@suse.de
- New rpm had removed "prereq" flag from installation script bits
  that is that `Requires(prereq)' is not valid anymore :(((
* Fri Feb 22 2013 mt@suse.com
- Updated syslog service activation description in the syslog(8)
  manual page (bnc#804299).
* Thu Jan 10 2013 mt@suse.com
- When exists, remove the broken link in multi-user.target.wants
  pointing to the common syslog.service file, which syslog-service
  package were providing before (bnc#790805).
* Wed Jan  9 2013 mt@suse.com
- Enable syslogd.service and create the syslog.service alias link
  in post install -- regardless of a preset config (bnc#790805).
* Sat Jan  5 2013 opensuse@cboltz.de
- Fixed typo in syslog.8 manual page
* Thu Nov 22 2012 mt@suse.com
- Fixed service file to use $ADDITIONAL_SOCKET without {} around
  as systemd expands them differently (bnc#788330).
* Tue Nov 20 2012 mt@suse.com
- Added version 2.0 to syslog-service to solve build problems
  of depending syslog daemon packages on openSUSE < 12.3, which
  require the 1.x syslog-service version with LSB init scripts.
* Tue Nov 13 2012 mt@suse.com
- Dropped SYSLOG_DAEMON variable from /etc/sysconfig/syslog.
  The syslogd package provides a specific syslogd.service file
  and creates an alias to syslog.service while activation now
  (bnc#788330).
- Dropped SYSLOG_REQUIRES_NETWORK, syslogd requires network.
- Updated documentation in syslog.8 manual page.
- Adopted logrotation and svcinfo files to use systemctl.
- Dropped /etc/init.d/syslog and earlysyslog init scripts,
  added /sbin/rcsyslog as compatibility forwarder to systemctl.
- Changed to install in /usr/sbin, compatibility link in /sbin.
- Changed to use _unitdir macro to install systemd unit files.
* Thu Oct 18 2012 coolo@suse.com
- buildrequire systemd by pkgconfig provides to get systemd-mini
  in build environment (to break cycle)
* Wed Oct 17 2012 werner@suse.de
- Avoid logrotate to exec for similar entries several times (bnc#713584)
* Wed Mar  7 2012 werner@suse.de
- Restart the syslog service only from post of the klogd package if
  the needed script is available (bnc#750478) Thanks to Lars Müller.
- Some cleanup due rpm lint warnings
* Tue Mar  6 2012 werner@suse.de
- Add `su news news' to logrotate entry for news log file (bnc#750263)
* Mon Feb 20 2012 mt@suse.com
- Detect if we have to use the new /run/systemd/journal/syslog
  socket instead of the /dev/log under newer systemd versions.
* Mon Feb 20 2012 mt@suse.com
- syslog-service: Added SYSLOG_REQUIRES_NETWORK variable allowing
  the user to configure (override) whether the syslog daemon config
  requires network or can be started early. Default is to detect
  it for syslogd and syslog-ng and to just start rsyslogd early
  with its normal config. Removed the rsyslog.early.conf use as it
  is usually not needed [enable on-disk queues] (bnc#728565).
* Fri Feb  3 2012 werner@suse.de
- Do not use early configuration setup for networkless configuration
  (bnc #728565)
* Tue Nov 22 2011 werner@suse.de
- Add pre requires for fillup and insserv to klogd package (bnc#731541)
* Mon Nov  7 2011 werner@suse.de
- Invert network/early logic for rsyslog (bnc#728565)
* Mon Oct 24 2011 werner@suse.de
- Wrap touch command with correct umask (bnc#725875)
* Fri Oct 21 2011 werner@suse.de
- Help the bash by using TMPDIR=/run to avoid trouble with the
  temporary files used for here-documents (bnc#724610)
* Tue Sep 20 2011 werner@suse.de
- Add syslink to /dev/null for earlysyslog service unit to avoid
  to start it twice with systemd
- Do not disable SysV service links with systemd
- For syslog service unit add conflicts witjh syslog-ng and rsyslog
  service units
* Fri Sep  2 2011 werner@suse.de
- Fix sysvinit boot script as klogd is not required anymore for
  rsyslogd and syslog-ng (bnc#715648)
* Thu Sep  1 2011 werner@suse.de
- Opps, move /etc/sysconfig/syslogd -> /etc/sysconfig/syslog
* Wed Aug 24 2011 mt@suse.de
- Improved syslog-service package summary
* Mon Aug 22 2011 werner@suse.de
- Package split: klogd -> klogd + syslog-service because the
  service boot scripts and service unit files do belong to all
  system logger daemons.
* Mon Aug 22 2011 werner@suse.de
- Check for klogd buitin service for syslog-ng and not syslogd
- Remove the klogd enable/disable service links if required
* Fri Aug 19 2011 werner@suse.de
- Make klogd.service and syslog.service static files and let
  systemd include syslog.core within syslog.service, only the
  syslog.core will be generated depending on /etc/sysconfig/syslog
- Do not touch the files as long as syslog.service or klogd.service
  are active
* Wed Aug 17 2011 werner@suse.de
- Add generator script for better support with systemd
* Tue Jun 28 2011 aj@suse.de
- Fix build - create ghost dir during install
* Mon Jun  6 2011 mt@suse.de
- Disabled klogd in /etc/init.d/syslog, when the syslog-ng.conf
  config file reads /proc/kmsg directly.
* Fri May 27 2011 lnussel@suse.de
- don't use /var/lock/subsys
* Fri May 27 2011 mt@suse.de
- Removed touch of obsolete /var/log/boot.log from spec post.
* Thu Jan 20 2011 mt@suse.de
- Improved systemd socket activation support to support multiple
  sockets and activation in forking mode (bnc#656104)
* Tue Nov 30 2010 werner@suse.de
- Make network a should have dependency of syslog service
* Fri Nov 26 2010 werner@suse.de
- Add systemd support that is that syslogd check for systemd log
  sockets (bnc#656104)
* Wed Sep 29 2010 aj@suse.de
- Create /var/run/rsyslog in case it's on tmpfs.
* Wed Aug 11 2010 puzel@novell.com
- logrotate.syslog: redirect output of postrotate script to
  /dev/null (bnc#626318)
* Fri Jul 16 2010 werner@suse.de
- Newer killproc sends only SIGTERM as required by LSB if -TERM is
  specified on the command line.  Use the default which is SIGTERM
* Tue May  4 2010 pczanik@fang.fa.gau.hu
- modify /etc/init.d/syslog for syslog-ng
  for https://features.opensuse.org/303793 compliance
* Mon Apr 12 2010 werner@suse.de
- Reformat boot script
* Wed Mar 31 2010 pczanik@genesi-usa.com
- modify /etc/init.d/syslog for syslog-ng 3.X
* Mon Mar 29 2010 werner@suse.de
- Do not lose signals during reseting signal flag (bnc#568150)
* Tue Jan 19 2010 werner@suse.de
- Forward read-only root file system patch from SLES11-SP1
- Correct time stamps of the patches
* Sun Dec 20 2009 jengelh@medozas.de
- enable parallel build
* Fri Dec 18 2009 agruen@suse.de
- Add read-only root filesystem support (fate#307235) using bind
  mounts.
* Tue Nov 24 2009 crrodriguez@opensuse.org
- refresh patches again
* Tue Nov  3 2009 coolo@novell.com
- updated patches to apply with fuzz=0
* Wed Sep  9 2009 mt@suse.de
- Added rsyslogd to the list of daemons in SYSLOG_DAEMON variable
  meta-data in sysconfig/syslog file, updated syslog.8 man page,
  improved rsyslogd native mode usage in the syslog init-script.
* Tue Aug 11 2009 jeffm@suse.de
- klogd: Silence System.map and symbol lookup warnings on modern
  kernels (bnc#505421)
* Thu Oct 16 2008 werner@suse.de
- Let's avoid currants in shell code of boot script (bnc#435525)
* Thu Oct  2 2008 mt@suse.de
- Fixed start in /etc/init.d/syslog script to restart rsyslogd
  with correct config when running in early mode (bnc#431599),
  changed to use earlysyslog in runleves 2 and 3 as well.
* Wed Sep  3 2008 mt@suse.de
- Added log files used by syslog-ng (and rsyslog) daemons to the
  /etc/logrotate.d/syslog file. Added logrotate to klogd requires.
- Added rsyslog support to the /etc/init.d/syslog and earlysyslog
  init scripts.
* Fri Aug 22 2008 ro@suse.de
- remove deprecated options from fillup_and_insserv call
* Wed Aug 13 2008 werner@suse.de
- Fix boot script and use correct Stop tags
* Fri May 30 2008 werner@suse.de
- No flock() as this seems to be broken in newer glibc (bnc#395114)
- No fortify, make sylog function of klogd private (bnc#395666)
* Wed May 28 2008 werner@suse.de
- Be able to write errors on writing pid file to tty (bnc#394787)
* Tue May 20 2008 mt@suse.de
- Added syslog(8) meta manual page to klogd package describing the
  syslog service (SYSLOG_DAEMON variable) handling (bnc#373960).
* Thu May  8 2008 werner@suse.de
- Clean syslog boot script and replace mkfifo with mknod (bnc#382236)
* Thu Apr  3 2008 mkoenig@suse.de
- readd removed defines for svcinfo path
* Tue Apr  1 2008 mkoenig@suse.de
- remove dir /usr/share/omc/svcinfo.d as it is provided now
  by filesystem
* Wed Mar 26 2008 werner@suse.de
- Do not exit within signal handlers
- Avoid race condition between fork() and signal handling
- Use setsid() only once
* Thu Jan 24 2008 werner@suse.de
- Add missing prerequirements (bug #355801)
* Thu Aug  9 2007 olh@suse.de
- remove inclusion of asm/bitops.h
* Mon Jun 18 2007 coolo@suse.de
- don't sleep during boot - and rather sync the logfile
* Mon May 14 2007 mt@suse.de
- Bug #256671: Changed default value of SYSLOG_DAEMON variable in
  /etc/sysconfig/syslog to "" (autodetect), adopted description.
  Added check to init scripts, that sets SYSLOG_DAEMON variable
  to one of the currently installed daemons in case it is empty
  or not up-to-date. Added reset of the variable in rpm postun.
* Tue Jan  9 2007 mt@suse.de
- Changed to install syslog.xml to /usr/share/omc/svcinfo.d,
  fate #301833.
* Thu Jan  4 2007 mt@suse.de
- Added syslogd path to processInformation tag in syslog.xml and
  moved it to klogd file list; used by syslog-ng too (FATE #301833)
- Improved run-time switch from syslogd to syslog-ng (bug #166933)
* Mon Dec 11 2006 mskibbe@suse.de
- add service xml file
* Wed Nov 15 2006 werner@suse.de
- Require rcnetwork due rcsyslog script does it (bug #214297)
* Wed Sep 13 2006 mt@suse.de
- Feature #300891: Remove SuSEconfig dependency of syslog-ng
  * Adopted /etc/init.d/syslog script to append additional
    sockets using -a options for syslog-ng as well.
* Thu Aug 24 2006 werner@suse.de
- Just use <linux/bitops.h> to to the same
* Fri Aug 18 2006 aj@suse.de
- Fix build.
* Tue Jul 11 2006 werner@suse.de
- Enable run-time switch from syslogd to syslog-ng (bug #166933)
* Mon May 22 2006 schwab@suse.de
- Don't strip binaries.
* Wed Feb 15 2006 mt@suse.de
- Added log rotation for /var/log/news/news.* files
* Wed Feb  8 2006 werner@suse.de
- Prevent directly the fortified cpp macros of the system syslog
  function and revert the skip of _FORTIFY_SOURCE.
* Wed Feb  8 2006 werner@suse.de
- Skip _FORTIFY_SOURCE for klogd/syslogd to be able to use
  our own functions without any filter (bug #147363)
* Wed Jan 25 2006 mls@suse.de
- converted neededforbuild to BuildRequires
* Tue Dec 20 2005 ro@suse.de
- remove explicit requires for devs
* Wed Oct  5 2005 werner@suse.de
- Enable 64 bit file interface
* Thu Sep 29 2005 dmueller@suse.de
- add norootforbuild
* Tue Sep 20 2005 werner@suse.de
- Avoid broken function implementation by fortified header
* Mon Jul 25 2005 mt@suse.de
- Bug #94743: Added note to the logrotate.syslog file about
  changing log file permissions in case syslog-ng is used.
* Fri Jun 17 2005 werner@suse.de
- Use -fpie/-pie
* Tue May 24 2005 werner@suse.de
- Fix of the priority and facility patch: do not pass SHOWPRI flag
  if no no facility and priority values are used (bug #85453).
* Tue Apr 19 2005 aj@suse.de
- Fix messages.
* Wed Mar  9 2005 ro@suse.de
- added split-provides for klogd
* Tue Mar  8 2005 mt@suse.de
- Bug #71264: added stop_on_removal/restart_on_removal to
  the spec file, fixed try-restart action in the init script
* Mon Mar  7 2005 mt@suse.de
- Bug #71085: removed syslog requirement from klogd sub-package
* Fri Feb 11 2005 mt@suse.de
- fixed rpm post-install script to switch SYSLOG_DAEMON to
  ourself if it is set to a daemon that is not installed
  (happens if we replace a syslog-ng installed before)
- fixed init scripts to not to report failures on stop
* Fri Feb 11 2005 ro@suse.de
- split off klogd package
- provide "syslog"
* Thu Jan 27 2005 werner@suse.de
- Add UTF8 compatibility (bug #49980)
- Make early syslog more smooth for e.g. rcsyslog restart
* Tue Jan 25 2005 ro@suse.de
- change klogd params from "-2" to "-x" by default
* Thu Jan 20 2005 coolo@suse.de
- only skip syslog start when booting into init 5
* Mon Jan 10 2005 coolo@suse.de
- add an early syslog that is started before network and checks
  for hostnames in syslog.conf
* Thu Dec 16 2004 werner@suse.de
- Add preserve percents patch to fix bug #49228
- Be sure that recvfrom() is awaken by SIGALRM and SIGTERM
* Tue Nov 16 2004 werner@suse.de
- Quieten the build
* Fri Oct 15 2004 werner@suse.de
- Add two patches from sgi (bug #46783)
  * Add logging on UNIX sockets
  * Add priority and facility marks in the log messages
* Thu Aug 19 2004 od@suse.de
- removed creation of unused /dev/:[0-5]; GetDevices of
  xorg-x11.rpm uses /dev/tty0 to find the virtual terminal of a
  local X-server (#43931)
* Thu Jul 29 2004 od@suse.de
- klogd now reads log buffer size from kernel. Falls back to
  probing as in dmesg (#39761).
* Tue May 18 2004 werner@suse.de
- Correct last change
* Mon May 17 2004 werner@suse.de
- No more symbol and EIP translation for 2.6 kernels (#40651)
* Mon Apr 19 2004 werner@suse.de
- Fix syslogd argument list handling (fix from Solar Designer)
* Wed Mar 24 2004 werner@suse.de
- Be prepared for udev (bug #36671)
* Thu Jan 29 2004 werner@suse.de
- Enable sample-s390.conf also for s390x (aka zSeries?, bug #34153)
* Mon Sep 29 2003 kukuk@suse.de
- Use SO_BSDCOMPAT only if defined
* Tue Sep 16 2003 werner@suse.de
- Clean last klogd24.dif
* Tue Sep  9 2003 werner@suse.de
- Is there a 128bit lseek around? Use some workarounds to get lseek
  working above LONG_MAX on x86_64 on /dev/kmem (kernel bug?)
* Mon Sep  8 2003 werner@suse.de
- Use special seek routine for signless addresses, fixes
  crash on i386.
* Wed Sep  3 2003 werner@suse.de
- Change symbol addresses to __off64_t and sizes to size_t (#28639)
* Tue Aug 26 2003 mt@suse.de
- bug #28949: added new 'Config' meta data to sysconfig file
- bug #27971: reconnect to log socket if a write fails with
  ECONNREFUSED or ENOTCONN, e.g. if the log socket has been
  reopened by "rcsyslog reload" while syslog-ng is used.
  new patch file: sysklogd-1.4.1-reopen.patch
* Fri Aug 15 2003 kukuk@suse.de
- Add devs to PreReq and don't create xconsole device itself
* Thu Aug  7 2003 werner@suse.de
- Change permissions of mail log files (bug #28561)
* Mon Jul 28 2003 werner@suse.de
- Fix trivial bug #27072: use warning instead of warn
* Fri Jul 25 2003 schwab@suse.de
- Fix uses of chown in %%post script.
* Fri Jul 18 2003 werner@suse.de
- Add DNS timeout patch from Olaf Kirch
* Tue May 20 2003 werner@suse.de
- Use large file support, gnore signal SIGXFSZ (bug #26960)
* Wed May 14 2003 kukuk@suse.de
- Fix klogd to build independend of installed kernel headers. klogd
  still does not work with 2.5.xx correct.
* Wed Apr 16 2003 coolo@suse.de
- fixing s390 build
* Wed Apr 16 2003 coolo@suse.de
- use BuildRoot
* Mon Feb 24 2003 schwab@suse.de
- Add workaround for use of kernel headers.
* Fri Jan 31 2003 werner@suse.de
- Add some code for supporting syslog-ng
- Split off boot script and sysconfig file from patch
* Wed Jan  8 2003 werner@suse.de
- bug #22695: add missed meta data within sysconfig file
- bug #22551: do not let read any user /var/log/messages
* Wed Dec 11 2002 werner@suse.de
- New log files for sorting priorities of mail messages (# 22394)
* Tue Nov  5 2002 ro@suse.de
- fillup/sysconfig.syslog: set kernel loglevel to 7 on s390/s390x
* Mon Oct 14 2002 ro@suse.de
- moved logrotate config for syslog's files to this package
- changed create to 640 for /var/log/mail (#20816)
* Mon Oct  7 2002 olh@suse.de
- honor the increased LOG_BUF_LEN in kernel/printk.c (#19888)
  LOG_BUFFER_SIZE=131072
* Tue Sep 10 2002 olh@suse.de
- provides syslog for hotplug
* Wed Aug 28 2002 nashif@suse.de
- fixed PreReq to use macros
* Fri Aug 23 2002 werner@suse.de
- Enable the `-2' of klogd option for clean and untraced oops.
* Fri Aug 16 2002 werner@suse.de
- Add PreReq (bug #18004)
- Change order of main and ipv6 patch
* Fri Aug  2 2002 kukuk@suse.de
- Add patch to enable IPv6 support (based on the USAGI version
  plus some fixes for IPv4 only).
* Wed Jul 17 2002 poeml@suse.de
- run with additional sockets from SYSLOGD_ADDITIONAL_SOCKET_* that
  other packages can fill up into /etc/sysconfig/syslog
* Mon Mar  4 2002 zoz@suse.de
- Change Required from $network to network
* Mon Mar  4 2002 ro@suse.de
- postinstall-script: disable perl-hack (-p for fillup_and_insserv)
- no extra insserv call
* Thu Feb 14 2002 werner@suse.de
- Fix the bug fix
* Thu Feb 14 2002 werner@suse.de
- Fix bug #12747: move to fillup_and_insserv and sysconfig scheme
* Wed Sep 19 2001 ro@suse.de
- fixed typo in rc_script SYSLOGD_PARAM -> SYSLOGD_PARAMS (#10950)
* Thu Aug 30 2001 werner@suse.de
- Fix bug #9096
- Make TAB a printable character
* Fri Jun 15 2001 schwab@suse.de
- Don't define __KERNEL__.
* Tue May 29 2001 werner@suse.de
- Update to version 1.4.1
- Porting our patches to this version
* Fri Apr 27 2001 mt@suse.de
- added syslog-ng hook in init script
* Tue Apr 17 2001 werner@suse.de
- Avoid zero bytes from kernel messages
* Thu Jan 11 2001 werner@suse.de
- Correct deep or relative symlink rcsyslog
* Thu Jan 11 2001 werner@suse.de
- Move syslogd and klogd to /sbin
- Change Required from $remote_fs to $network
* Thu Dec  7 2000 werner@suse.de
- Change boot.log to localmessages and add local0 upto local7
* Mon Dec  4 2000 ro@suse.de
- added var/log/boot.log
* Tue Nov 28 2000 ro@suse.de
- fixed startscript
* Mon Nov 13 2000 ro@suse.de
- fixed to compile on 2.4 kernel header
* Tue Oct 17 2000 bk@suse.de
- add sample-s390.conf for s390.
* Thu Sep 14 2000 werner@suse.de
- Fix format handling within Syslog()
* Wed Sep 13 2000 werner@suse.de
- Fix the two printline bugs in syslogd.c
* Tue Sep 12 2000 werner@suse.de
- Fix missed format
* Wed May 24 2000 schwab@suse.de
- Fix resource leak.
* Tue Feb 29 2000 schwab@suse.de
- Fix type of last arg to recvfrom
- Add group tag.
* Sun Feb 27 2000 kukuk@suse.de
- Move /usr/man -> /usr/share/man
* Fri Feb 11 2000 werner@suse.de
- The pid file is /var/run/syslogd.pid not /var/run/syslogd.conf
* Wed Nov 17 1999 kukuk@suse.de
- Add fix to syslogd for SIGHUP race condition
* Thu Nov  4 1999 werner@suse.de
- next typo fix in comment in /etc/syslogd.conf
* Thu Nov  4 1999 bs@suse.de
- typo fix in comment in /etc/syslogd.conf
* Tue Oct 26 1999 mge@suse.de
- (sysklogd-1.3-forw.patch) Andreas Siegert <afx@suse.de>
  Added -t flag that triggers tagging of forwarded messages with
  the sending hosts name as seen by the forwarder. Useful for
  relaying syslog from DMZs through the firwall to an internal
  loghost. Format is "<""hostname"
* Fri Oct  8 1999 werner@suse.de
- New version 1.3.33
* Thu Sep 30 1999 werner@suse.de
- Udatet version of nodos patch
* Fri Sep 24 1999 werner@suse.de
- Disable *.alert message on root tty's
* Mon Sep 13 1999 bs@suse.de
- ran old prepare_spec on spec file to switch to new prepare_spec.
* Fri Sep 10 1999 ro@suse.de
- fixed nodos patch
* Mon Sep  6 1999 werner@suse.de
- Avoid possible crash if no kernel symbols are available.
* Fri Sep  3 1999 werner@suse.de
- Update to new version 1.3.32
- Add sparc patch
- Add security patch (DOS)
- Make it work with alpha (time_t and size_t)
- wallmsg() only for user processes marked in utmp
- The last character of al kernel log is ascii null
- Lock fd of the socket to the syslogd
* Thu Sep  2 1999 werner@suse.de
- Use RPM_OPT_FLAGS
- Use a pipe to redirect console message to xconsole
- Make reading of ring buffer an (undocumented) option (-r
  reading, -R reading and clearing, both one shot)
* Tue Aug 31 1999 werner@suse.de
- Use 16k buffer because newer kernels do have such a big log
- Avoid trouble due longjmp and fork with a few variables
* Tue Aug 31 1999 werner@suse.de
- Use sysctl argument 3 (Read up to the last 4k of messages in the
  ring buffer) instead of 2 (Read from the log) if one shot method
  for klogd is used.
* Sat Aug 21 1999 garloff@suse.de
- syslog.conf: Only write *.crit synchronously
* Fri Jan  8 1999 florian@suse.de
- /var/log/news should be owned by news.news
* Thu Jan  7 1999 bs@suse.de
- fixed comment in syslog.conf
* Mon Dec 14 1998 ro@suse.de
- removed noreplace from syslogd.conf: necessary change for news-logs
* Fri Dec 11 1998 ro@suse.de
- split up news logs
* Wed Dec  9 1998 ro@suse.de
- changed syslog.conf to back to suse-defaults
* Tue Dec  8 1998 ro@suse.de
- updated init script and added link rcsyslog
* Mon Dec  7 1998 ro@suse.de
- update to 1.3-30
- syslog.conf marked as config(noreplace)
* Fri Dec  4 1998 ro@suse.de
- bootscript: silently restart if already running on "start"
* Wed Dec  2 1998 werner@suse.de
- New boot script syslog
* Mon Jun 22 1998 ro@suse.de
- used patches from trevor@jpj.net to build for glibc:
  - renamed syslogd's dprintf to syslog_dprintf
  - don't declare sys_errlist
  - use sys/time.h instead of linux/time.h
* Tue Mar 10 1998 ro@suse.de
- react if KERNEL_LOGLEVEL=""
- added SYSLOGD_PARAMS
* Tue Mar 10 1998 ro@suse.de
- added KERNEL_LOGLEVEL to fillup for rc.config and rcfile
* Fri Feb 27 1998 florian@suse.de
- removed duplicate entry for news messages in syslog.conf
* Wed Oct 22 1997 ro@suse.de
- removed doinst.sh from specfile-filelist
* Sun Jun  1 1997 bs@suse.de
- don't include log files under var/log but touch them in doinst.sh
* Thu May 29 1997 bs@suse.de
- cleared var/log/warn
* Wed Apr 30 1997 florian@suse.de
- add lots of fixes from debian and other places
- new /etc/syslog.conf: mail/news messages are in separate files
* Wed Apr 30 1997 bs@suse.de
  added & when starting syslogd.
* Thu Jan  2 1997 bs@suse.de
  runlevel value changed to S09 and K35
* Thu Jan  2 1997 florian@suse.de
- klogd liest jetzt wieder die System.map ein.
- Neue Option "-x", mit der man das Lesen der System.map
  abschalten kann.
- Start- und Stop-Scripte sind jetzt im Paket und nicht mehr in
  aaa_base.tgz.
